@@ -67,6 +67,8 @@ class AutoMapper(AutoMapperContainer):
         copy_all_unmapped_properties: bool = False,
         copy_all_unmapped_properties_exclude: Optional[List[str]] = None,
         log_level: Optional[Union[int, str]] = None,
+        enable_schema_reduction: bool = False,
+        remove_duplicates_by_columns: Optional[List[str]] = None,
     ):
         """
         Creates an AutoMapper
@@ -86,7 +88,7 @@ class AutoMapper(AutoMapperContainer):
         :param include_null_properties: If you want to include null properties
         :param use_single_select: This is a faster way to run the AutoMapper since it will select
                 all the columns at once.
-                However this makes it harder to debug since you don't know what column failed
+                However, this makes it harder to debug since you don't know what column failed
         :param verify_row_count: verifies that the count of rows remains the same before and after the transformation
         :param skip_schema_validation: skip schema checks on these columns
         :param skip_if_columns_null_or_empty: skip creating the record if any of these columns are null or empty
@@ -95,6 +97,8 @@ class AutoMapper(AutoMapperContainer):
         :param copy_all_unmapped_properties: copy any property that is not explicitly mapped
         :param copy_all_unmapped_properties_exclude: exclude these columns when copy_all_unmapped_properties is set
         :param logger: logger used to log informational messages
+        :param enable_schema_reduction: enables remove properties from schema that are not present in the automapper
+        :param remove_duplicates_by_columns: remove duplicate rows where the value of these columns match
         """
         super().__init__()
         self.view: Optional[str] = view
@@ -117,11 +121,13 @@ class AutoMapper(AutoMapperContainer):
         self.keep_null_rows: bool = keep_null_rows
         self.filter_by: Optional[str] = filter_by
         self.logger: Logger = logger  # type: ignore
+        self.log_level: Optional[Union[int, str]] = log_level or os.environ.get(
+            "LOGLEVEL"
+        )
         if not self.logger:
             self.logger = getLogger(__name__)
-            log_level = log_level or os.environ.get("LOGLEVEL")
-            if log_level:
-                self.logger.setLevel(log_level)
+            if self.log_level is not None:
+                self.logger.setLevel(self.log_level)
             if self.logger.handlers:
                 pass
             else:
@@ -142,8 +148,13 @@ class AutoMapper(AutoMapperContainer):
         ] = copy_all_unmapped_properties_exclude
 
         self.entity_name: Optional[str] = None
+        self.enable_schema_reduction: bool = enable_schema_reduction
+        if enable_schema_reduction:
+            self.skip_schema_validation = []  # no need to filter out extensions
+        self.remove_duplicates_by_columns: Optional[
+            List[str]
+        ] = remove_duplicates_by_columns
 
-    # noinspection PyMethodMayBeStatic,PyUnusedLocal
     def _transform_with_data_frame_single_select(
         self, df: DataFrame, source_df: DataFrame, keys: List[str]
     ) -> DataFrame:
@@ -289,8 +300,9 @@ class AutoMapper(AutoMapperContainer):
                             "Looks like the elements of the array have different structures.  "
                             "All items in an array should have the exact same structure.  "
                             "You can pass in include_nulls to AutoMapperDataTypeComplexBase to force it to create "
-                            "null values for each element in the structure. "
+                            "null values for each element in the structure. \n"
                         )
+                        # find the data types of each item in the list
                     column_values: Optional[List[Any]] = None
                     # This can cause GC overhead limit reached error obfuscating the actual error
                     # try:
@@ -310,13 +322,15 @@ class AutoMapper(AutoMapperContainer):
                     #     column_values = None
 
                     msg += self._get_message_for_exception(
-                        column_name=column_name + ": " + str(check_schema_result),
+                        column_name=column_name,
+                        check_schema_result=check_schema_result,
                         df=df,
                         e=e2,
                         source_df=source_df,
                         column_values=column_values,
                     )
                     raise AutoMapperAnalysisException(
+                        automapper_name=self.view,
                         msg=msg,
                         column_name=column_name,
                         check_schema_result=check_schema_result,
@@ -325,7 +339,12 @@ class AutoMapper(AutoMapperContainer):
         except Exception as e:
             self.logger.error("====  OOPS ===========")
             msg = self._get_message_for_exception(
-                column_name="", df=df, e=e, source_df=source_df, column_values=None
+                column_name="",
+                check_schema_result=None,
+                df=df,
+                e=e,
+                source_df=source_df,
+                column_values=None,
             )
             raise Exception(msg) from e
 
@@ -388,6 +407,7 @@ class AutoMapper(AutoMapperContainer):
                 if source_df is not None:
                     msg += self._get_message_for_exception(
                         column_name=column_name,
+                        check_schema_result=None,
                         df=df,
                         e=e,
                         source_df=source_df,
@@ -398,6 +418,7 @@ class AutoMapper(AutoMapperContainer):
                 msg = (
                     self._get_message_for_exception(
                         column_name=column_name,
+                        check_schema_result=None,
                         df=df,
                         e=e,
                         source_df=source_df,
@@ -418,10 +439,11 @@ class AutoMapper(AutoMapperContainer):
 
         return df
 
-    @staticmethod
     def _get_message_for_exception(
+        self,
         *,
         column_name: str,
+        check_schema_result: Optional[CheckSchemaResult],
         df: DataFrame,
         e: Exception,
         source_df: DataFrame,
@@ -440,8 +462,18 @@ class AutoMapper(AutoMapperContainer):
         # write out the full list of columns
         columns_in_source: List[str] = list(source_df.columns)
         columns_in_destination: List[str] = list(df.columns)
-        msg: str = f", Processing column:[{column_name}]"
-        msg += f"column values: [{','.join(str(column_values))}]"
+        msg: str = ""
+        if column_name is not None:
+            msg += f", Processing column:[{column_name}]\n"
+        if check_schema_result is not None:
+            msg += check_schema_result.to_string(
+                include_info=True
+                if self.log_level and self.log_level == "DEBUG"
+                else False
+            )
+            msg += "\n"
+        if column_values is not None:
+            msg += f"column values: [{','.join(str(column_values))}]"
         msg += str(e)
         msg += f", Source columns:[{','.join(columns_in_source)}]"
         msg += f", Destination columns:[{','.join(columns_in_destination)}]"
@@ -537,6 +569,12 @@ class AutoMapper(AutoMapperContainer):
         if not self.keep_duplicates:
             result_df = result_df.drop_duplicates()
 
+        if (
+            self.remove_duplicates_by_columns
+            and len(self.remove_duplicates_by_columns) > 0
+        ):
+            result_df = result_df.drop_duplicates(self.remove_duplicates_by_columns)
+
         # if view was specified then create that view
         if self.view:
             result_df.createOrReplaceTempView(self.view)
@@ -616,6 +654,7 @@ class AutoMapper(AutoMapperContainer):
             include_null_properties=self.include_null_properties,
             skip_schema_validation=self.skip_schema_validation,
             skip_if_columns_null_or_empty=self.skip_if_columns_null_or_empty,
+            enable_schema_reduction=self.enable_schema_reduction,
         )
 
         self.entity_name = entity.__class__.__name__
