@@ -18,6 +18,7 @@ class AutoMapperWithComplex(AutoMapperContainer):
         include_null_properties: bool,
         skip_schema_validation: List[str],
         skip_if_columns_null_or_empty: Optional[List[str]],
+        enable_schema_reduction: bool,
     ) -> None:
         """
         Create mapping for an entity
@@ -32,11 +33,36 @@ class AutoMapperWithComplex(AutoMapperContainer):
         """
         super().__init__()
 
+        # check if entity is using Extension and if yes, get schema WITH extension
+        field_names: List[str] = list(entity.get_child_mappers().keys())
+        has_extension: bool = "extension" in field_names
+
+        # TODO: should detect from schema what fields are being used
+        standard_extension_fields: List[str] = [
+            "valueBoolean",
+            "valueCode",
+            "valueDate",
+            "valueDateTime",
+            "valueDecimal",
+            "valueId",
+            "valueInteger",
+            "valuePositiveInt",
+            "valueString",
+            "valueTime",
+            "valueUnsignedInt",
+            "valueUri",
+            "valueUrl",
+            "valueReference",
+            "valueCodeableConcept",
+            "valueAddress",
+        ]
         # ask entity for its schema
         schema: Union[StructType, DataType, None] = entity.get_schema(
-            include_extension=include_extension
+            include_extension=include_extension or has_extension,
+            extension_fields=standard_extension_fields,
         )
         column_schema: Dict[str, StructField] = {}
+        self.enable_schema_reduction: bool = enable_schema_reduction
         if schema is not None and isinstance(schema, StructType):
             # if entity has an extension then ask the extension for its schema
             column_name: str
@@ -44,8 +70,10 @@ class AutoMapperWithComplex(AutoMapperContainer):
             for column_name, mapper in entity.get_child_mappers().items():
                 if column_name == "extension":
                     extension_schema: Union[StructType, DataType, None]
+                    # since there is a column called extension then get the schema with extension
                     extension_schema = mapper.get_schema(
-                        include_extension=include_extension
+                        include_extension=include_extension or has_extension,
+                        extension_fields=standard_extension_fields,
                     )
                     if extension_schema is not None:
                         if (
@@ -59,6 +87,11 @@ class AutoMapperWithComplex(AutoMapperContainer):
             column_schema = (
                 {f.name: f for f in schema.fields} if schema and use_schema else {}
             )
+            # column_schema = (
+            #     {f.name: f for f in schema.fields if f.name in field_names}
+            #     if schema and use_schema
+            #     else {}
+            # )
 
         self.generate_mappers(
             mappers_dict={
@@ -68,4 +101,5 @@ class AutoMapperWithComplex(AutoMapperContainer):
             include_null_properties=include_null_properties or use_schema,
             skip_schema_validation=skip_schema_validation,
             skip_if_columns_null_or_empty=skip_if_columns_null_or_empty,
+            enable_schema_reduction=self.enable_schema_reduction,
         )
