@@ -5,6 +5,7 @@ from pyspark.sql import Column, DataFrame
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col, when, lit
 from pyspark.sql.types import DataType, StructField
+from pyspark.sql.utils import AnalysisException
 from spark_data_frame_comparer.schema_comparer import SchemaComparer
 
 from spark_auto_mapper.automappers.automapper_base import AutoMapperBase
@@ -21,14 +22,19 @@ class AutoMapperWithColumnBase(AutoMapperBase):
         value: AutoMapperAnyDataType,
         column_schema: Optional[StructField],
         include_null_properties: bool,
+        enable_schema_reduction: bool,
         skip_if_columns_null_or_empty: Optional[List[str]] = None,
     ) -> None:
+        """
+        This class handles assigning to a single column
+
+        """
         super().__init__()
         # should only have one parameter
         self.dst_column: str = dst_column
         self.column_schema: Optional[StructField] = column_schema
         self.value: AutoMapperDataTypeBase = (
-            AutoMapperValueParser.parse_value(value)
+            AutoMapperValueParser.parse_value(column_name=dst_column, value=value)
             if not isinstance(value, AutoMapperDataTypeBase)
             else value
         )
@@ -39,11 +45,18 @@ class AutoMapperWithColumnBase(AutoMapperBase):
             self.value.include_null_properties(
                 include_null_properties=include_null_properties
             )
+        self.enable_schema_reduction: bool = enable_schema_reduction
 
     def get_column_spec(self, source_df: Optional[DataFrame]) -> Column:
         # if value is an AutoMapper then ask it for its column spec
         if isinstance(self.value, AutoMapperDataTypeBase):
             child: AutoMapperDataTypeBase = self.value
+            if self.column_schema:
+                self.value.set_schema(
+                    column_name=self.dst_column,
+                    column_path=self.dst_column,
+                    column_data_type=self.column_schema.dataType,
+                )
             column_spec = child.get_column_spec(
                 source_df=source_df, current_column=None
             )
@@ -59,7 +72,18 @@ class AutoMapperWithColumnBase(AutoMapperBase):
                 )
             # if the type has a schema then apply it
             if self.column_schema:
-                column_spec = column_spec.cast(self.column_schema.dataType)
+                column_data_type: DataType = self.column_schema.dataType
+                if self.enable_schema_reduction:
+                    # first disable generation of null properties since we are doing schema reduction
+                    self.value.include_null_properties(include_null_properties=False)
+                    # second ask the mapper to reduce schema that is not used
+                    column_data_type = self.value.filter_schema_by_fields_present(
+                        column_name=self.dst_column,
+                        column_path=self.dst_column,
+                        column_data_type=column_data_type,
+                        skip_null_properties=True,
+                    )
+                column_spec = column_spec.cast(column_data_type)
             # if dst_column already exists in source_df then prepend with ___ to make it unique
             if source_df is not None and self.dst_column in source_df.columns:
                 return column_spec.alias(f"___{self.dst_column}")
@@ -99,17 +123,24 @@ class AutoMapperWithColumnBase(AutoMapperBase):
             column_spec = child.get_column_spec(
                 source_df=source_df, current_column=None
             )
-            # get just a few rows so Spark can infer the schema
-            first_few_rows_df: DataFrame = (
-                source_df.alias("b").select(column_spec).limit(100)
-            )
-            source_schema: DataType = first_few_rows_df.schema[0].dataType
-            desired_schema: DataType = self.column_schema.dataType
-            result = SchemaComparer.compare_schema(
-                parent_column_name=self.dst_column,
-                source_schema=source_schema,
-                desired_schema=desired_schema,
-            )
-            return CheckSchemaResult(result=result)
+            # result = child.check_schema(
+            #     parent_column=self.dst_column, source_df=source_df
+            # )
+
+            try:
+                # get just a few rows so Spark can infer the schema
+                first_few_rows_df: DataFrame = (
+                    source_df.alias("b").select(column_spec).limit(100)
+                )
+                source_schema: DataType = first_few_rows_df.schema[0].dataType
+                desired_schema: DataType = self.column_schema.dataType
+                result = SchemaComparer.compare_schema(
+                    parent_column_name=self.dst_column,
+                    source_schema=source_schema,
+                    desired_schema=desired_schema,
+                )
+                return CheckSchemaResult(result=result)
+            except AnalysisException:
+                return None
         else:
             return None
