@@ -24,7 +24,7 @@ class AutoMapperArrayDistinctDataType(AutoMapperTextLikeBase):
         self.value: List[AutoMapperDataTypeBase] = [
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
             for value in args
         ]
 
@@ -44,3 +44,9 @@ class AutoMapperArrayDistinctDataType(AutoMapperTextLikeBase):
             item.include_null_properties(
                 include_null_properties=include_null_properties
             )
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
