@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, List, Union
 
 from pyspark.sql import Column, DataFrame
 
@@ -13,7 +13,7 @@ class AutoMapperBooleanDataType(AutoMapperDataTypeBase):
         self.value: AutoMapperDataTypeBase = (
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
         )
 
     def get_column_spec(
@@ -24,3 +24,9 @@ class AutoMapperBooleanDataType(AutoMapperDataTypeBase):
             source_df=source_df, current_column=current_column
         ).cast("boolean")
         return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
