@@ -25,7 +25,7 @@ class AutoMapperCoalesceDataType(AutoMapperTextLikeBase):
         self.value: List[AutoMapperDataTypeBase] = [
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
             for value in args
         ]
 
@@ -45,3 +45,9 @@ class AutoMapperCoalesceDataType(AutoMapperTextLikeBase):
             item.include_null_properties(
                 include_null_properties=include_null_properties
             )
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
