@@ -2,17 +2,17 @@ from typing import List, Union, Optional
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import concat
+
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
-from spark_auto_mapper.data_types.mixins.has_children_mixin import HasChildrenMixin
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
 from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeTextType
 from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperWrapperType
 
 
-class AutoMapperConcatDataType(AutoMapperArrayLikeBase, HasChildrenMixin):
+class AutoMapperConcatDataType(AutoMapperArrayLikeBase):
     """
     Concatenates multiple strings or arrays together
     """
@@ -31,7 +31,7 @@ class AutoMapperConcatDataType(AutoMapperArrayLikeBase, HasChildrenMixin):
         self.value: List[AutoMapperDataTypeBase] = [
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
             for value in args
         ]
 
@@ -47,7 +47,7 @@ class AutoMapperConcatDataType(AutoMapperArrayLikeBase, HasChildrenMixin):
     def get_column_spec(
         self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
-        self.ensure_children_have_same_properties()
+        self.ensure_children_have_same_properties(skip_null_properties=False)
         column_spec = concat(
             *[
                 col.get_column_spec(source_df=source_df, current_column=current_column)
@@ -59,9 +59,3 @@ class AutoMapperConcatDataType(AutoMapperArrayLikeBase, HasChildrenMixin):
     @property
     def children(self) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
         return self.value
-
-    def get_fields(self) -> List[str]:
-        return HasChildrenMixin.get_fields(self)
-
-    def add_missing_values_and_order(self, expected_keys: List[str]) -> None:
-        HasChildrenMixin.add_missing_values_and_order(self, expected_keys=expected_keys)
