@@ -1,4 +1,5 @@
-from typing import Callable, List, Optional, TypeVar, Union, cast, Type
+from abc import abstractmethod
+from typing import Callable, List, Optional, TypeVar, Union, cast, Type, Dict
 
 # noinspection PyPackageRequirements
 from pyspark.sql import Column, DataFrame
@@ -6,7 +7,10 @@ from pyspark.sql import Column, DataFrame
 from typing import TYPE_CHECKING
 
 # noinspection PyPackageRequirements
-from pyspark.sql.types import StructType, StringType, DataType
+from pyspark.sql.types import StructType, StringType, DataType, ArrayType, StructField
+from spark_auto_mapper.automappers.check_schema_result import CheckSchemaResult
+from spark_auto_mapper.helpers.field_node import FieldNode
+from spark_auto_mapper.helpers.python_keyword_cleaner import PythonKeywordCleaner
 
 if TYPE_CHECKING:
     from spark_auto_mapper.data_types.amount import AutoMapperAmountDataType
@@ -37,6 +41,11 @@ class AutoMapperDataTypeBase:
     Base class for all Automapper data types
     """
 
+    def __init__(self) -> None:
+        self.column_name: Optional[str] = None
+        self.schema: Optional[Union[StructType, DataType]] = None
+        self.children_schema: Optional[Union[StructType, DataType]] = None
+
     # noinspection PyMethodMayBeStatic
     def get_column_spec(
         self, source_df: Optional[DataFrame], current_column: Optional[Column]
@@ -244,7 +253,7 @@ class AutoMapperDataTypeBase:
 
 
         :param self: Set by Python.  No need to pass.
-        :return: a flatten automapper type
+        :return: A flatten automapper type
         :example: A.flatten(A.column("column"))
         """
         from spark_auto_mapper.data_types.flatten import AutoMapperFlattenDataType
@@ -411,7 +420,7 @@ class AutoMapperDataTypeBase:
     # override this if your inherited class has a defined schema
     # noinspection PyMethodMayBeStatic
     def get_schema(
-        self, include_extension: bool
+        self, include_extension: bool, extension_fields: Optional[List[str]] = None
     ) -> Optional[Union[StructType, DataType]]:
         return None
 
@@ -657,8 +666,367 @@ class AutoMapperDataTypeBase:
             ),
         )
 
-    def get_fields(self) -> List[str]:
-        return []
+    def check_schema(
+        self, parent_column: Optional[str], source_df: Optional[DataFrame]
+    ) -> Optional[CheckSchemaResult]:
+        """
+        Checks the schema
+
+
+        :param parent_column: parent column
+        :param source_df: source data frame
+        :return: result of checking schema
+        """
+        return None
+
+    def ensure_children_have_same_properties(self, skip_null_properties: bool) -> None:
+        """
+        Spark cannot handle children of a list having different properties.
+        So we find the superset of properties and add them as null.
+
+        Spark expects the children of a list to have properties in the same order
+        So if we have a schema we need to order in that order otherwise just make sure all children have the same order
+        """
+        if self.children is None or not isinstance(self.children, list):
+            return
+
+        children_properties: Dict[AutoMapperDataTypeBase, List[FieldNode]] = {
+            v: v.get_fields(skip_null_properties=skip_null_properties)
+            for v in self.children
+        }
+        # find superset of properties and get them in the right order
+        superset_of_all_properties: List[str] = []
+        for child, child_properties in children_properties.items():
+            for child_property in child_properties:
+                if child_property.name not in superset_of_all_properties:
+                    superset_of_all_properties.append(child_property.name)
+
+        ordered_superset_of_all_properties: List[str] = []
+        if self.children_schema and isinstance(self.children_schema, StructType):
+            field: StructField
+            for field in self.children_schema.fields:
+                field_name_safe: str = field.name
+                if field_name_safe in superset_of_all_properties:
+                    ordered_superset_of_all_properties.append(field_name_safe)
+            # confirm that there wasn't any field missing from schema
+            missing_properties: List[str] = []
+            for child_property_name in superset_of_all_properties:
+                if child_property_name not in ordered_superset_of_all_properties:
+                    missing_properties.append(child_property_name)
+            assert len(missing_properties) == 0, (
+                f"List had items with properties not present in schema:"
+                f" {','.join(missing_properties)}."
+                f" list from mappers:{','.join(superset_of_all_properties)}."
+                f" list from schema:{','.join(ordered_superset_of_all_properties)}."
+            )
+        else:
+            ordered_superset_of_all_properties = superset_of_all_properties
+
+        for child in [v for v in self.children]:
+            child.add_missing_values_and_order(ordered_superset_of_all_properties)
+            child.include_null_properties(
+                True
+            )  # must include null properties or will strip the ones we just added
+
+    def set_children_schema(
+        self, schema: Optional[Union[StructType, DataType]]
+    ) -> None:
+        """
+        Used by the parent to set the schema for the children of this list
+
+        :param schema: children schema
+        """
+        self.children_schema = schema
+
+    def get_fields(self, skip_null_properties: bool) -> List[FieldNode]:
+        """
+        Returns unique list of fields from the children
+
+        """
+        fields: List[FieldNode] = []
+
+        children: List[AutoMapperDataTypeBase]
+        if not isinstance(self.children, list):
+            children = [self.children]
+        else:
+            children = self.children
+        for child in children:
+            child_fields: List[FieldNode] = child.get_fields(
+                skip_null_properties=skip_null_properties
+            )
+            for child_field in child_fields:
+                if child_field not in fields:
+                    fields.append(child_field)
+        return fields
 
     def add_missing_values_and_order(self, expected_keys: List[str]) -> None:
-        return
+        if not self.children:
+            return
+
+        children: List[AutoMapperDataTypeBase]
+        if not isinstance(self.children, list):
+            children = [self.children]
+        else:
+            children = self.children
+        for child in children:
+            child.add_missing_values_and_order(expected_keys=expected_keys)
+
+    def _filter_schema_by_fields_present_for_array(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+        skip_null_properties: bool,
+    ) -> DataType:
+        assert isinstance(
+            column_data_type, ArrayType
+        ), f"{type(column_data_type)} should be ArrayType for {column_name} with path {column_path}"
+
+        self.ensure_children_have_same_properties(
+            skip_null_properties=skip_null_properties
+        )
+
+        element_type = column_data_type.elementType
+        children: Union[
+            AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]
+        ] = self.children
+        assert isinstance(children, list), f"{type(children)} should be a list"
+        if len(children) > 0:
+            should_skip_null_properties: bool = len(children) == 0
+            child: AutoMapperDataTypeBase
+            for child in children:
+                child.filter_schema_by_fields_present(
+                    column_name=column_name,
+                    column_path=column_path,
+                    column_data_type=element_type,
+                    skip_null_properties=should_skip_null_properties,
+                )
+
+        return column_data_type
+
+    # noinspection PyUnusedLocal
+    def _filter_schema_by_fields_present_for_struct(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+        skip_null_properties: bool,
+    ) -> DataType:
+        assert isinstance(
+            column_data_type, StructType
+        ), f"{type(column_data_type)} should be StructType for {column_name} with path {column_path}"
+
+        children: Union[
+            "AutoMapperDataTypeBase", List["AutoMapperDataTypeBase"]
+        ] = self.children
+        if isinstance(children, list) and len(children) > 0:
+            child: "AutoMapperDataTypeBase"
+            for index, child in enumerate(children):
+                child.filter_schema_by_fields_present(
+                    column_name=column_data_type.fields[index].name,
+                    column_path=f"{column_path}.{column_data_type.fields[index].name}",
+                    column_data_type=column_data_type.fields[index].dataType,
+                    skip_null_properties=skip_null_properties,
+                )
+        elif not isinstance(children, list) and children is not None:
+            child = children
+            child.filter_schema_by_fields_present(
+                column_name=column_data_type.fields[0].name,
+                column_path=f"{column_path}.{column_data_type.fields[0].name}",
+                column_data_type=column_data_type.fields[0].dataType,
+                skip_null_properties=skip_null_properties,
+            )
+
+        fields: List[FieldNode] = self.get_fields(skip_null_properties=True)
+        new_column_data_type: DataType = column_data_type
+        if isinstance(new_column_data_type, StructType) and len(fields) > 0:
+            # return only the values that match the fields
+            new_column_data_type.fields = [
+                c
+                for c in new_column_data_type.fields
+                if c.name in [f.name for f in fields] or c.nullable is False
+            ]
+            new_column_data_type.names = [f.name for f in new_column_data_type.fields]
+
+        return column_data_type
+
+    def filter_schema_by_fields_present(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+        skip_null_properties: bool,
+    ) -> DataType:
+        # if this is a basic type so nothing to do
+        if not isinstance(column_data_type, StructType) and not isinstance(
+            column_data_type, ArrayType
+        ):
+            return column_data_type
+
+        if isinstance(column_data_type, ArrayType):
+            return self._filter_schema_by_fields_present_for_array(
+                column_name=column_name,
+                column_path=column_path,
+                column_data_type=column_data_type,
+                skip_null_properties=skip_null_properties,
+            )
+
+        assert isinstance(
+            column_data_type, StructType
+        ), f"{type(column_data_type)} should be StructType for {column_name} with path {column_path}"
+
+        return self._filter_schema_by_fields_present_for_struct(
+            column_name=column_name,
+            column_path=column_path,
+            column_data_type=column_data_type,
+            skip_null_properties=skip_null_properties,
+        )
+
+    def _set_schema_for_array(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+    ) -> None:
+        assert isinstance(
+            column_data_type, ArrayType
+        ), f"{type(column_data_type)} should be ArrayType for {column_name} with path {column_path}"
+
+        element_type = column_data_type.elementType
+        self.set_children_schema(element_type)
+        children: Union[
+            AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]
+        ] = self.children
+        assert isinstance(children, list), f"{type(children)} should be a list"
+        if len(children) > 0:
+            child: AutoMapperDataTypeBase
+            for child in children:
+                child.set_schema(
+                    column_name=column_name,
+                    column_path=column_path,
+                    column_data_type=element_type,
+                )
+
+    # noinspection PyUnusedLocal
+    def _set_schema_for_struct(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+    ) -> None:
+        assert isinstance(
+            column_data_type, StructType
+        ), f"{type(column_data_type)} should be StructType for {column_name} with path {column_path}"
+
+        children: Union[
+            "AutoMapperDataTypeBase", List["AutoMapperDataTypeBase"]
+        ] = self.children
+        if isinstance(children, list) and len(children) > 0:
+            child: "AutoMapperDataTypeBase"
+            for index, child in enumerate(children):
+                assert child.column_name
+                clean_child_name: str = PythonKeywordCleaner.from_python_safe(
+                    child.column_name
+                )
+                matching_fields = [
+                    f for f in column_data_type.fields if f.name == clean_child_name
+                ]
+                assert len(matching_fields) == 1, (
+                    f"Schema match failed for column {column_path}.{clean_child_name}"
+                    f" in schema fields"
+                    f": [{','.join([f.name for f in column_data_type.fields])}]"
+                )
+                field: StructField = matching_fields[0]
+                child.set_schema(
+                    column_name=field.name,
+                    column_path=f"{column_path}.{field.name}",
+                    column_data_type=field.dataType,
+                )
+        elif not isinstance(children, list) and children is not None:
+            child = children
+            assert child.column_name
+            clean_child_name = PythonKeywordCleaner.from_python_safe(child.column_name)
+            matching_fields = [
+                f for f in column_data_type.fields if f.name == clean_child_name
+            ]
+            assert len(matching_fields) == 1, (
+                f"Schema match failed for column {column_path}.{clean_child_name}"
+                f" in schema fields"
+                f": [{','.join([f.name for f in column_data_type.fields])}]"
+            )
+            field = matching_fields[0]
+            child.set_schema(
+                column_name=field.name,
+                column_path=f"{column_path}.{field.name}",
+                column_data_type=field.dataType,
+            )
+
+    def set_schema(
+        self,
+        *,
+        column_name: Optional[str],
+        column_path: Optional[str],
+        column_data_type: DataType,
+    ) -> None:
+        """
+        Sets the schema for this AutoMapper type
+
+
+        :param column_name: column name
+        :param column_path: full path to column
+        :param column_data_type: schema for this mapper
+        """
+
+        self.schema = column_data_type
+
+        # if this is a basic type so nothing to do
+        if not isinstance(column_data_type, StructType) and not isinstance(
+            column_data_type, ArrayType
+        ):
+            return
+
+        if isinstance(column_data_type, ArrayType):
+            self._set_schema_for_array(
+                column_name=column_name,
+                column_path=column_path,
+                column_data_type=column_data_type,
+            )
+            return
+
+        assert isinstance(
+            column_data_type, StructType
+        ), f"{type(column_data_type)} should be StructType for {column_name} with path {column_path}"
+
+        self._set_schema_for_struct(
+            column_name=column_name,
+            column_path=column_path,
+            column_data_type=column_data_type,
+        )
+
+    @property
+    @abstractmethod
+    def children(
+        self,
+    ) -> Union["AutoMapperDataTypeBase", List["AutoMapperDataTypeBase"]]:
+        """
+        The subclasses should implement this
+        """
+        raise NotImplementedError
+
+    def set_column_name(self, column_name: str) -> None:
+        """
+        Sets the name for this automapper
+        """
+        self.column_name = column_name
+
+    def __repr__(self) -> str:
+        return (
+            f"{self.column_name}: {self.__class__.__name__}"
+            if self.column_name is not None
+            else self.__class__.__name__
+        )
