@@ -1,4 +1,4 @@
-from typing import Optional, List
+from typing import Optional, List, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import coalesce, to_date
@@ -31,7 +31,7 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
         self.value: AutoMapperDataTypeBase = (
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
         )
         self.formats: Optional[List[str]] = formats
 
@@ -88,3 +88,9 @@ class AutoMapperDateDataType(AutoMapperDataTypeBase):
                 source_df=source_df, current_column=current_column
             )
             return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
