@@ -26,7 +26,7 @@ class AutoMapperHashDataType(AutoMapperTextLikeBase):
         self.value: List[AutoMapperDataTypeBase] = [
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
             for value in args
         ]
 
@@ -40,3 +40,9 @@ class AutoMapperHashDataType(AutoMapperTextLikeBase):
             ]
         ).cast("string")
         return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
