@@ -20,6 +20,10 @@ class AutoMapperIfDataType(AutoMapperDataTypeBase, Generic[_TAutoMapperDataType]
     If check returns value if the checks passes else when_not
     """
 
+    @property
+    def children(self) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
+
     def __init__(
         self,
         column: AutoMapperColumnOrColumnLikeType,
@@ -34,25 +38,25 @@ class AutoMapperIfDataType(AutoMapperDataTypeBase, Generic[_TAutoMapperDataType]
             self.check: Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]] = [
                 a
                 if isinstance(a, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(a)
+                else AutoMapperValueParser.parse_value(value=a)
                 for a in check
             ]
         else:
             self.check = (
                 check
                 if isinstance(check, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(check)
+                else AutoMapperValueParser.parse_value(value=check)
             )
         self.value: AutoMapperDataTypeBase = (
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
         )
         if else_:
             self.else_: AutoMapperDataTypeBase = (
                 cast(AutoMapperDataTypeBase, else_)
                 if isinstance(value, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(value)
+                else AutoMapperValueParser.parse_value(value=value)
             )
         else:
             self.else_ = AutoMapperDataTypeLiteral(None)
