@@ -1,4 +1,4 @@
-from typing import Generic, Optional, TypeVar
+from typing import Generic, Optional, TypeVar, List, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.utils import AnalysisException
@@ -31,14 +31,14 @@ class AutoMapperIfColumnExistsType(
         super().__init__()
 
         self.column: AutoMapperColumnOrColumnLikeType = (
-            AutoMapperValueParser.parse_value(column)
+            AutoMapperValueParser.parse_value(value=column)
         )
         self.if_exists_column: Optional[AutoMapperDataTypeBase] = None
         if if_exists:
             self.if_exists_column = (
                 if_exists
                 if isinstance(if_exists, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(if_exists)
+                else AutoMapperValueParser.parse_value(value=if_exists)
             )
 
         self.if_not_exists: Optional[AutoMapperDataTypeBase] = None
@@ -46,7 +46,7 @@ class AutoMapperIfColumnExistsType(
             self.if_not_exists = (
                 if_not_exists
                 if isinstance(if_not_exists, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(if_not_exists)
+                else AutoMapperValueParser.parse_value(value=if_not_exists)
             )
 
     def get_column_spec(
@@ -80,3 +80,9 @@ class AutoMapperIfColumnExistsType(
                     source_df=source_df, current_column=current_column
                 )
         return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return [c for c in [self.if_exists_column, self.if_not_exists] if c is not None]
