@@ -1,4 +1,4 @@
-from typing import TypeVar, Union, Generic, Optional, cast
+from typing import TypeVar, Union, Generic, Optional, cast, List
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import when
@@ -36,16 +36,16 @@ class AutoMapperIfNotNullOrEmptyDataType(
         self.value: AutoMapperDataTypeBase = (
             value
             if isinstance(value, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(value)
+            else AutoMapperValueParser.parse_value(value=value)
         )
         if when_null_or_empty:
-            self.when_null: AutoMapperDataTypeBase = (
+            self.when_null_or_empty: AutoMapperDataTypeBase = (
                 cast(AutoMapperDataTypeBase, when_null_or_empty)
                 if isinstance(value, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(value)
+                else AutoMapperValueParser.parse_value(value=value)
             )
         else:
-            self.when_null = AutoMapperDataTypeLiteral(None)
+            self.when_null_or_empty = AutoMapperDataTypeLiteral(None)
 
     def include_null_properties(self, include_null_properties: bool) -> None:
         self.value.include_null_properties(
@@ -62,7 +62,7 @@ class AutoMapperIfNotNullOrEmptyDataType(
             | self.check.get_column_spec(
                 source_df=source_df, current_column=current_column
             ).eqNullSafe(""),
-            self.when_null.get_column_spec(
+            self.when_null_or_empty.get_column_spec(
                 source_df=source_df, current_column=current_column
             ),
         ).otherwise(
@@ -72,3 +72,22 @@ class AutoMapperIfNotNullOrEmptyDataType(
         )
 
         return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        result: List[AutoMapperDataTypeBase] = []
+        if self.value is not None:
+            result = result + (
+                self.value.children
+                if isinstance(self.value.children, list)
+                else [self.value.children]
+            )
+        if self.when_null_or_empty is not None:
+            result = result + (
+                self.when_null_or_empty.children
+                if isinstance(self.when_null_or_empty.children, list)
+                else [self.when_null_or_empty.children]
+            )
+        return result
