@@ -5,10 +5,10 @@ from pyspark.sql.functions import array, coalesce
 from pyspark.sql.functions import lit, filter
 from pyspark.sql.functions import when
 from pyspark.sql.types import StructType, ArrayType, StructField, DataType
+from spark_auto_mapper.automappers.check_schema_result import CheckSchemaResult
 
 from spark_auto_mapper.data_types.array_base import AutoMapperArrayLikeBase
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
-from spark_auto_mapper.data_types.mixins.has_children_mixin import HasChildrenMixin
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
 from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeSimpleType
@@ -16,7 +16,7 @@ from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeSimp
 _T = TypeVar("_T", bound=Union[AutoMapperNativeSimpleType, AutoMapperDataTypeBase])
 
 
-class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
+class AutoMapperList(AutoMapperArrayLikeBase, Generic[_T]):
     """
     Base class for lists
     Generics:  https://mypy.readthedocs.io/en/stable/generics.html
@@ -58,7 +58,7 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
         elif isinstance(value, AutoMapperDataTypeBase):
             self.value = value
         elif isinstance(value, List):
-            self.value = [AutoMapperValueParser.parse_value(v) for v in value]
+            self.value = [AutoMapperValueParser.parse_value(value=v) for v in value]
             # if there are more than two items we have to maintain the same schema in children or Spark errors
             if include_null_properties:
                 self.include_null_properties(
@@ -66,6 +66,7 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
                 )
         else:
             raise ValueError(f"{type(value)} is not supported")
+        self.skip_null_properties: bool = not include_null_properties
 
     def include_null_properties(self, include_null_properties: bool) -> None:
         """
@@ -73,6 +74,7 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
 
         :param include_null_properties: include if true
         """
+        self.skip_null_properties = not include_null_properties
         if isinstance(self.value, list):
             for item in self.value:
                 item.include_null_properties(
@@ -91,7 +93,9 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
 
 
         """
-        self.ensure_children_have_same_properties()
+        self.ensure_children_have_same_properties(
+            skip_null_properties=self.skip_null_properties
+        )
         if isinstance(
             self.value, str
         ):  # if the src column is just string then consider it a sql expression
@@ -145,8 +149,10 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
 
     # noinspection PyMethodMayBeStatic
     def get_schema(
-        self, include_extension: bool
+        self, include_extension: bool, extension_fields: Optional[List[str]] = None
     ) -> Optional[Union[StructType, DataType]]:
+        if self.schema:
+            return self.schema
         if self.children_schema:
             return self.children_schema
         if isinstance(self.value, list):
@@ -155,7 +161,10 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
                 first_element = self.value[0]
                 schema: Optional[
                     Union[StructType, DataType]
-                ] = first_element.get_schema(include_extension=include_extension)
+                ] = first_element.get_schema(
+                    include_extension=include_extension,
+                    extension_fields=extension_fields,
+                )
                 if schema is None:
                     return None
                 return StructType([StructField("extension", ArrayType(schema))])
@@ -192,8 +201,16 @@ class AutoMapperList(AutoMapperArrayLikeBase, HasChildrenMixin, Generic[_T]):
     def children(self) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
         return self.value
 
-    def get_fields(self) -> List[str]:
-        return HasChildrenMixin.get_fields(self)
+    def check_schema(
+        self, parent_column: Optional[str], source_df: Optional[DataFrame]
+    ) -> Optional[CheckSchemaResult]:
+        # children: List[AutoMapperDataTypeBase]
+        # if not isinstance(self.children, list):
+        #     children = [self.children]
+        # else:
+        #     children = self.children
 
-    def add_missing_values_and_order(self, expected_keys: List[str]) -> None:
-        HasChildrenMixin.add_missing_values_and_order(self, expected_keys=expected_keys)
+        # child: AutoMapperDataTypeBase
+        # for child in children:
+        #     result = child.check_schema(parent_column=None, source_df=source_df)
+        return None
