@@ -1,4 +1,4 @@
-from typing import Dict, Optional
+from typing import Dict, Optional, List, Union
 
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import when
@@ -32,7 +32,7 @@ class AutoMapperMapDataType(AutoMapperDataTypeExpression):
             key: (
                 value
                 if isinstance(value, AutoMapperDataTypeBase)
-                else AutoMapperValueParser.parse_value(value)
+                else AutoMapperValueParser.parse_value(value=value)
             )
             for key, value in mapping.items()
         }
@@ -40,7 +40,7 @@ class AutoMapperMapDataType(AutoMapperDataTypeExpression):
         self.default: AutoMapperDataTypeBase = (
             default
             if isinstance(default, AutoMapperDataTypeBase)
-            else AutoMapperValueParser.parse_value(default)
+            else AutoMapperValueParser.parse_value(value=default)
         )
 
     def get_column_spec(
@@ -78,3 +78,9 @@ class AutoMapperMapDataType(AutoMapperDataTypeExpression):
 
         assert column_spec is not None
         return column_spec
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return list(self.mapping.values())
