@@ -47,7 +47,7 @@ class AutoMapperNullRemover(AutoMapperDataTypeBase, Generic[_T]):
         if isinstance(value, AutoMapperDataTypeBase):
             self.value = value
         elif isinstance(value, List):
-            self.value = [AutoMapperValueParser.parse_value(v) for v in value]
+            self.value = [AutoMapperValueParser.parse_value(value=v) for v in value]
             # if there are more than two items we have to maintain the same schema in children or Spark errors
             if include_null_properties:
                 self.include_null_properties(
@@ -99,14 +99,23 @@ class AutoMapperNullRemover(AutoMapperDataTypeBase, Generic[_T]):
 
     # noinspection PyMethodMayBeStatic
     def get_schema(
-        self, include_extension: bool
+        self, include_extension: bool, extension_fields: Optional[List[str]] = None
     ) -> Optional[Union[StructType, DataType]]:
         if isinstance(self.value, list):
             # get schema for first element
             if len(self.value) > 0:
                 first_element = self.value[0]
-                schema = first_element.get_schema(include_extension=include_extension)
+                schema = first_element.get_schema(
+                    include_extension=include_extension,
+                    extension_fields=extension_fields,
+                )
                 if schema is None:
                     return None
                 return StructType([StructField("extension", ArrayType(schema))])
         return None
+
+    @property
+    def children(
+        self,
+    ) -> Union[AutoMapperDataTypeBase, List[AutoMapperDataTypeBase]]:
+        return self.value
