@@ -8,7 +8,6 @@ from pytest import approx
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -44,11 +43,11 @@ def test_auto_mapper_amount(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["age"], col("b.my_age").cast("double").alias("age")
+    assert str(sql_expressions["age"]) == str(
+        col("b.my_age").cast("double").alias("age")
     )
-    assert_expressions_are_equal(
-        sql_expressions["null_col"], lit(None).cast("double").alias("null_col")
+    assert str(sql_expressions["null_col"]) == str(
+        lit(None).cast("double").alias("null_col")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
