@@ -11,11 +11,12 @@ def test_auto_mapper_handles_duplicates(spark_session: SparkSession) -> None:
     clean_spark_session(session=spark_session)
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran'),
-            (2, 'Qureshi', 'Imran'),
-            (3, 'Qureshi', 'Imran2'),
-            (4, 'Vidal', 'Michael'),
-        ], ['member_id', 'last_name', 'first_name']
+            (1, "Qureshi", "Imran"),
+            (2, "Qureshi", "Imran"),
+            (3, "Qureshi", "Imran2"),
+            (4, "Vidal", "Michael"),
+        ],
+        ["member_id", "last_name", "first_name"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -23,13 +24,9 @@ def test_auto_mapper_handles_duplicates(spark_session: SparkSession) -> None:
     # Act
     mapper = AutoMapper(
         view="members", source_view="patients", keys=["member_id"]
-    ).columns(
-        dst1="src1", dst2=A.column("last_name"), dst3=A.column("first_name")
-    )
+    ).columns(dst1="src1", dst2=A.column("last_name"), dst3=A.column("first_name"))
 
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
