@@ -8,7 +8,6 @@ from pyspark.sql.functions import lit
 from pyspark.sql.types import StringType, LongType
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -41,11 +40,10 @@ def test_automapper_if_not_null(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["age"],
+    assert str(sql_expressions["age"]) == str(
         when(col("b.my_age").isNull(), lit("100").cast(StringType()).cast(LongType()))
         .otherwise(col("b.my_age").cast(LongType()))
-        .alias("age"),
+        .alias("age")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
