@@ -7,7 +7,6 @@ from pyspark.sql.functions import substring
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -36,9 +35,8 @@ def test_auto_mapper_left(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["my_column"],
-        substring(col("b.last_name"), 0, 3).alias("my_column"),
+    assert str(sql_expressions["my_column"]) == str(
+        substring(col("b.last_name"), 0, 3).alias("my_column")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
